@@ -185,16 +185,23 @@ def worker_task(
                         logger.error(
                             f"executed task [failure]: {task_reference} failures: {e}"
                         )
-                        logger.error(f"---- START OF ERROR----")
-                        logger.error(f"Task {task_type}:")
-                        for l in serialisation_utils.dump(task_details).split("\n"):
-                            logger.error(l)
-                        for l in traceback.format_exception(
-                            etype=type(e), value=e, tb=e.__traceback__,
-                        ):
-                            for sl in l.split("\n"):
-                                logger.error(f"{sl}")
-                        logger.error(f"---- END OF ERROR ----")
+                        try:
+                            logger.error(f"---- START OF ERROR----")
+                            logger.error(f"Task {task_type}:")
+                            for l in serialisation_utils.dump(
+                                unwrap(task_details)
+                            ).split("\n"):
+                                logger.error(l)
+                            for l in traceback.format_exception(
+                                etype=type(e), value=e, tb=e.__traceback__,
+                            ):
+                                for sl in l.split("\n"):
+                                    logger.error(f"{sl}")
+                            logger.error(f"---- END OF ERROR ----")
+                        except Exception as e2:
+                            logger.error(
+                                f"Exception raised: {e2}  whilst logging exection: {e}"
+                            )
                         task.on_task_failure(e, duration)
                     else:
                         end = time.time()
